function [res,CV] = allStats(name)

take_all = false;

raw_dir = '../Raw';
data_dir = '../DataMat';
if take_all
  results_dir = '../Results_full';
else
  results_dir = '../Results';
end
fidS = fopen(sprintf('%s/strandnessStats_%s.txt', results_dir, name),'w');
fidC = fopen(sprintf('%s/cvStats_%s.txt', results_dir, name),'w');
realName = name;
fname = sprintf('%s/%s.mat', data_dir, name);
load(sprintf('%s/c_elegans.WS200.mat', raw_dir), 'SGD');
%load Raw/numObj.mat numObjF numObjR
if ~exist(fname,'file'),
    error('prog:input','File %s does not exist\n',fname);
end

%% load data
%load (fname,'DataFread1','DataRread1');
%use.dataF = DataFread1;
%use.dataR = DataRread1;
if take_all
  load(fname, 'DataFread1', 'DataRread1', 'DataFconv', 'DataRconv');
  use.dataF = DataFread1;
  use.dataR = DataRread1;
else
  load (fname,'SubFread1','SubRread1','SubFread1_ext36','SubRread1_ext36', 'SubFconv', 'SubRconv');
  use.dataF = SubFread1; %use only starting points
  use.dataR = SubRread1; 
end


%% strandness
% go over all chromosomes, and ask how many reads match the expected
% objects on F and R.
allReads = 0;
allReadsSingleFeatures = 0;
correctReads = 0;
outsideReads = 0;
oppositeReads = 0;
chr_num = 7;
for c = 1:chr_num,
    load(sprintf('%s/c_elegans.numObj_chr%i.mat', raw_dir, c), 'numObjF', 'numObjR');
    indF = numObjF>0;
    indR = numObjR>0;
    indOnlyF = indF & ~indR;
    indOnlyR = indR & ~indF;
    indIntergenic = ~indF & ~indR;
    
    indSingleFeature = indOnlyF | indOnlyR | indIntergenic;
    
    allReads = allReads+sum(use.dataF{c})+sum(use.dataR{c});
    allReadsSingleFeatures = allReadsSingleFeatures + ...
        sum(use.dataF{c}(indSingleFeature)) + sum(use.dataR{c}(indSingleFeature));
    correctReads = correctReads + sum(use.dataF{c}(indOnlyF)) + sum(use.dataR{c}(indOnlyR));
    oppositeReads = oppositeReads + sum(use.dataF{c}(indOnlyR)) + sum(use.dataR{c}(indOnlyF));
    outsideReads = outsideReads + sum(use.dataF{c}(indIntergenic)) + sum(use.dataR{c}(indIntergenic));
end
res = [allReads allReadsSingleFeatures correctReads oppositeReads outsideReads];
fprintf(fidS,'%s\t%d\t%d\t%d\n',realName,res(3:5));
fclose(fidS);


%% coefficient of variance
% go over all genes, and calculate their CV = std/mean
if take_all
  use.DataF = DataFconv;
  use.DataR = DataRconv;
else
  %use.DataF = SubFread1_ext36;
  %use.DataR = SubRread1_ext36;
  use.DataF = SubFconv;
  use.DataR = SubRconv;
end

if 0
%load(sprintf('%s/IsAlt.mat', data_dir), 'is_alt');
%idx = ~[is_alt];
idx = false(1, length(SGD.chr));
for s = 1:length(SGD.chr),
  idx(s) = size(SGD.pos{s},1)==1;
end
sum(idx)
SGD.chr = SGD.chr(idx);
SGD.watson = SGD.watson(idx);
SGD.name = {SGD.name{idx}};
SGD.status = {SGD.status{idx}};
SGD.pos = {SGD.pos{idx}};
end

G = length(SGD.chr);
CV = NaN*ones(G,2);

for g=1:G
    ch = SGD.chr(g);
    ind = [];
    for p = 1:size(SGD.pos{g}, 1),
      ind = unique([ind, SGD.pos{g}(p,1):SGD.pos{g}(p,2)]);
    end
    if SGD.watson(g)
        %ind = SGD.pos(g,1):SGD.pos(g,2);
        dat = use.DataF{ch}(ind);
    else
        %ind = SGD.pos(g,2):SGD.pos(g,1);
        dat = use.DataR{ch}(ind);
    end
    
    meanExp = mean(dat);
    stdExp = std(dat);
    CV(g,:) = [meanExp stdExp./meanExp];
    
end
% top-50%
fprintf('%3.2f ', prctile(CV(:,1), [10:10:100]));
[sortedExp ind] = sort(CV(:,1),'descend'); %#ok<ASGLU> %sort by expression
%G_half = find(sortedExp>=18.54, 1, 'last');
G_half = ceil(G/2);
CV(ind(G_half,1))
G_half
oneCVnum = nanmean(CV(ind(1:G_half),2));
fprintf(fidC,'%s\t%.5f\n',realName,oneCVnum);
fclose(fidC);