function compareRNASeq2array(lib)

take_all = true
PLOT_FIGURES = false;

raw_dir = '../Raw';
data_dir = '../DataMat';

if take_all
  results_dir = '../Results_full';
else
  results_dir = '../Results';
end
figures_dir = '../Figures';

load(sprintf('%s/c_elegans.WS200.mat', raw_dir), 'SGD');

fname = sprintf('%s/%s.mat', data_dir, lib);
L = load(fname);
if take_all
  use.DataF = L.DataFconv;
  use.DataR = L.DataRconv;
else
  %use.DataF = SubFread1_ext36;
  %use.DataR = SubRread1_ext36;
  use.DataF = L.SubFconv;
  use.DataR = L.SubRconv;
end
total_num_reads = 0;
for c = 1:length(use.DataF),
  total_num_reads = total_num_reads + sum(L.SubFread1{c}) + sum(L.SubRread1{c});
end
total_num_reads = total_num_reads;
clear L

load(sprintf('%s/c_elegans.y_series.gene_expr_RMA_avg.mat', raw_dir), 'gene_ids', 'expr');

SGD.rnaseq_avg = nan(length(SGD.chr), 1);
SGD.array_avg = nan(length(SGD.chr), size(expr,2));
for g = 1:length(SGD.chr),
  %fprintf('%i\r',g);
  ch = SGD.chr(g);
  ind = [];
  for n = 1:size(SGD.pos{g}, 1),
    ind = unique([ind, SGD.pos{g}(n,1):SGD.pos{g}(n,2)]);
  end
  if SGD.watson(g)
    dat = use.DataF{ch}(ind);
  else
    dat = use.DataR{ch}(ind);
  end
  SGD.rnaseq_avg(g) = mean(dat);
  idx = strmatch(SGD.name{g}(6:end), gene_ids, 'exact');
  if ~isempty(idx)
    SGD.array_avg(g,:) = expr(idx,:);
  end
end

dat1 = SGD.rnaseq_avg/total_num_reads;
dat1 = dat1./(max(dat1)-min(dat1(dat1~=-inf)));
dat1 = log2(dat1);
dat2 = SGD.array_avg(:,7); % already in log2
dat2 = exp(dat2/log2(exp(1))); % non-log values
dat2 = dat2./(max(dat2)-min(dat2(dat2~=-inf)));
dat2 = log2(mean(dat2,2)); % mean
ind = isfinite(dat1) & isfinite(dat2);
mn = nanmean(abs(dat1(ind)-dat2(ind))); 
dat2 = dat2 - mn; % normalise with mean deviation
idx = find(~isnan(dat1) & ~isnan(dat2) & isfinite(dat1) & isfinite(dat2));
p = polyfit(dat1(idx),dat2(idx),1); % linear fit
dat1 = p(1)*dat1 + p(2); % and respective mapping

%dat2 = SGD.array_avg; % already in log2
allCorrToArrays = zeros(size(dat2,2),2);
allRMSEToArrays = zeros(size(dat2,2),1);
for n = 1:size(dat2,2),
  ind = isfinite(dat1) & isfinite(dat2(:,n));
  t = corrcoef(dat1(ind), dat2(ind,n));
  allCorrToArrays(n,1) = t(1,2);
  allCorrToArrays(n,2) = corr(dat1(ind), dat2(ind,n), 'type', 'Spearman');
  allRMSEToArrays(n) = sqrt(nanmean((dat1(ind)-dat2(ind,n)).^2));
end

allCorrToArrays
median(allCorrToArrays,1)
allRMSEToArrays
median(allRMSEToArrays)


if PLOT_FIGURES,
  
  %% correlation plot
  figure(1); clf
  bar(allCorrToArrays', 'grouped');
  legend({'Y001', 'Y002', 'Y003', 'Y004', 'Y005', 'Y006', 'Y007', 'Y008', 'Y009', 'Y010'}, 'Location', 'BestOutside');
  set(gca, 'XTickLabel', {'Pearson', 'Spearman'});
  ylabel('Correlation RNA-Seq vs microarray');
  set(gca, 'Ylim', [0 1]);
  %print(gcf,'-dpng','-r150', sprintf('%s/RNAvsArrays.%s.corr.png', figures_dir, lib));
  print(gcf,'-depsc','-r300', sprintf('%s/RNAvsArrays.%s.corr.eps', figures_dir, lib));
  close all;
  
  %% scatter plot library vs. RNAvsDNA array expression
  for n = 1:size(dat2,2),
    figure(n); clf
    ind = isfinite(dat1) & isfinite(dat2(:,n));
    plot(dat1(ind),dat2(ind,n),'.');
    xlabel(lib,'interpreter','none');
    ylabel('RNA-Seq vs microarray');
    title(sprintf('corr=%f', allCorrToArrays(n)));
    grid
    %print(gcf,'-dpng','-r150', sprintf('%s/RNAvsArrays.%s.Y%i.splot.png', figures_dir, lib, n));
    print(gcf,'-depsc','-r300', sprintf('%s/RNAvsArrays.%s.Y%i.splot.eps', figures_dir, lib, n));
    close all;
  end
  

  %% Q-Q plot library vs. array expression
  for n = 1:size(dat2,2),
    figure(n); clf;
    ind = isfinite(dat1) & isfinite(dat2(:,n));
    qqplot(dat1(ind), dat2(ind,n));
    xlabel(sprintf('%s quantiles',lib),'interpreter','none')
    ylabel('RNA vs RNA microarray quantiles');
    grid
    title(sprintf('qqplot of %s and RNA-Seq vs microarray',lib),'interpreter','none')
    hold on
    plot(-20:20,-20:20,'r+','linewidth',2);
    hold off
    set(gca,'box','off','tickdir','out')
    set(gca,'Xlim',[-20 20],'Ylim',[-20 20]);
    %print(gcf,'-dpng','-r150',sprintf('%s/RNAvsArrays.%s.Y%i.qqplot.png', figures_dir, lib, n));
    print(gcf,'-depsc','-r300',sprintf('%s/RNAvsArrays.%s.Y%i.qqplot.eps', figures_dir, lib, n));
  end
 
end

keyboard