"""This script merges two SAM files from a paired-end experiments and sets the flags 0, 6, 7 """
import sys
import random

def parse_options(argv):
    """Parses options from the command line"""

    from optparse import OptionParser, OptionGroup

    parser = OptionParser()
    required = OptionGroup(parser, 'REQUIRED')
    required.add_option('-i', '--infile', dest='infile', metavar='FILE', help='alignment file in SAM format with paired reads', default='-')
    required.add_option('-o', '--outfile', dest='outfile', metavar='PATH', help='outfile', default='-')
    parser.add_option_group(required)

    (options, args) = parser.parse_args()
    
    if len(argv) < 2:
        parser.print_help()
        sys.exit(2)

    return options


def main():
    """Writes paired reads defined by contig number, start of read 1 and start of read 2, strand."""

    contigs = dict({'I': 1, 'II': 2, 'III': 3, 'IV': 4, 'V': 5, 'X': 6, 'MtDNA': 7});

    subN = 2500000*2.71
    num_reads = 26528034
    read_len = 76
    sample_fac = subN/num_reads

    options = parse_options(sys.argv)
    outfileF = open(options.outfile + 'F', 'w')
    outfileR = open(options.outfile + 'R', 'w')
    
    line_counter = 1
    infile = open(options.infile, 'r')
    sl = ''
    line = infile.readline()		
    while 1:
        if (line_counter % 1000000) == 0:
            print '[ %s ]' % line_counter
        if (line_counter>1 and sl==''):
            line_counter += 1
            line = infile.readline()
            if line=='':
                break
            sl = line.strip().split('\t')
        if line_counter==1:
            sl = line.strip().split('\t')
        try:
            flag = int(sl[1])
        except ValueError:
            print line
            continue

        paired = (flag & 1)
        pairIsMapped = ((flag & 4)==0) and ((flag & 8)==0)
        queryStrand = flag & 16
        mateStrand = flag & 32
        insertSize = int(sl[8])
        notPrimaryAlignment = (flag & 256)==256
        
        if not pairIsMapped:
            sl = ''
            sl2 = ''
            continue
        
        line2 = infile.readline()
        if line2=='':
            break
        line_counter += 1
        sl2 = line2.strip().split('\t')
        if sl[0] != sl2[0]:
            sl = sl2
            sl2 = ''
            continue
        assert(sl[0]==sl2[0])
        
        if queryStrand==mateStrand or abs(insertSize > 500) or notPrimaryAlignment or sl[2]!=sl2[2] or int(sl[3])==int(sl2[3]):
            sl = ''
            sl2 = ''
            continue

        if int(sl[3])>=int(sl2[3]):
            tmp = sl
            sl = sl2
            sl2 = tmp
        assert(int(sl[3])<int(sl2[3]))

        if sample_fac > random.random():
            if queryStrand==0:
                outfileF.write(str(contigs[sl[2]]) + '\t' + sl[3] + '\t' + sl[7] + '\t' + sl[5] + '\t' + sl2[5] + '\n')
            else:
                outfileR.write(str(contigs[sl[2]]) + '\t' + sl[3] + '\t' + sl[7] + '\t' + sl[5] + '\t' + sl2[5] + '\n')
                
        sl = ''
        sl2 = ''    
    
    outfileF.close()
    outfileR.close()
    infile.close()

if __name__ == '__main__':
    main()
