"""This script merges two SAM files from a paired-end experiments and sets the flags 0, 6, 7 """
import sys

def parse_options(argv):
    """Parses options from the command line"""

    from optparse import OptionParser, OptionGroup

    parser = OptionParser()
    required = OptionGroup(parser, 'REQUIRED')
    required.add_option('-l', '--linfile', dest='linfile', metavar='FILE', help='alignment file in SAM format (left part of pair)', default='-')
    required.add_option('-r', '--rinfile', dest='rinfile', metavar='FILE', help='alignment file in SAM format (right part of pair)', default='-')
    required.add_option('-o', '--outfile', dest='outfile', metavar='PATH', help='outfile', default='-')
    optional = OptionGroup(parser, 'OPTIONAL')
    optional.add_option('-v', '--verbose', dest='verbose', action='store_true', help='verbosity', default=False)
    parser.add_option_group(required)
    parser.add_option_group(optional)

    (options, args) = parser.parse_args()
    
    if len(argv) < 4:
        parser.print_help()
        sys.exit(2)

    return options


def edit_flag(infile, outfile, flag_append, verbose):
    """Adds flag_append to current flag"""
    
    line_counter = 0
    for line in open(infile, 'r'):
        line_counter += 1
        if verbose and (line_counter % 1000000) == 0:
            print '[ %s ]' % line_counter
        sl = line.strip().split('\t')
        try:
            flag = int(sl[1])
        except ValueError:
            print line
            continue
        newflag = flag | flag_append
        sl[1] = str(newflag)
        newsl = ''
        for col in sl:
            newsl += (col + '\t')
        print >> outfile, newsl[:-1]

def main():
    """Function merging two SAM files with paired-end reads"""

    options = parse_options(sys.argv)

    outfile = open(options.outfile, 'w')
    if options.verbose:
        print "Parsing file %s" % (options.linfile)
    edit_flag(options.linfile, outfile, 1|64, options.verbose)
    if options.verbose:
        print "Parsing file %s" % (options.rinfile)
    edit_flag(options.rinfile, outfile, 1|128, options.verbose)

    outfile.close()

if __name__ == '__main__':
    main()
