function [] = sam2Mat_strandSpec(name)
%go over each read or pair, and add it to the data vectors
tic;

raw_dir = '../Raw';
data_dir = '../DataMat';
  
%% Initiate variables
%load Raw/chrLen.mat chromLengths
chromLengths = [15072421 15279324 13783682 17493784 20924143 17718854 13794]

chrNum = length(chromLengths);

DataFconv = cell(1,chrNum);
DataRconv = cell(1,chrNum);
DataF = cell(1,chrNum);
DataR = cell(1,chrNum);
DataFread1 = cell(1,chrNum);
DataRread1 = cell(1,chrNum);

SubFread1 = cell(1,chrNum);
SubRread1 = cell(1,chrNum);
SubFread1_ext36 = cell(1,chrNum);
SubRread1_ext36 = cell(1,chrNum);
SubFconv = cell(1,chrNum);
SubRconv = cell(1,chrNum);

for c=1:chrNum
    DataF{c} = zeros(1,chromLengths(c),'single');
    DataR{c} = zeros(1,chromLengths(c),'single');
    DataFread1{c} = zeros(1,chromLengths(c),'single');
    DataRread1{c} = zeros(1,chromLengths(c),'single');
    DataFconv{c} = zeros(1,chromLengths(c),'single');
    DataRconv{c} = zeros(1,chromLengths(c),'single');
    SubFread1{c} = zeros(1,chromLengths(c),'single');
    SubRread1{c} = zeros(1,chromLengths(c),'single');
    SubFread1_ext36{c} = zeros(1,chromLengths(c),'single');
    SubRread1_ext36{c} = zeros(1,chromLengths(c),'single');
    SubFconv{c} = zeros(1,chromLengths(c),'single');
    SubRconv{c} = zeros(1,chromLengths(c),'single');
end

%% Some libraries are flipped
% In the dUTP and NNSR libraries, the second read correspond to the
% transcribed strand, and not the first, so the data should be flipped.
flip = 0;
if (strcmp(name(1:4),'dUTP') || strcmp(name(1:4),'NNSR') || strcmp(name(1:4),'Park'))
    verbose('data is flipped\n',10);
    flip = 1;
end

%% parse the sam file
% read the qltout file, line by line, and parse the mapping
fileName = sprintf('%s/%s.sam', raw_dir, name);
f1 = fopen(fileName);
chrCellDef = {'I', 'II', 'III', 'IV', 'V', 'X', 'MtDNA'};
chrCell = {};
i=1;
lines_taken=0;
subN = 2500000*2.71;
num_reads = 26528034;
read_len = 76;
sample_fac = subN/num_reads;

while(1)
    if (mod(i,1e6)==0), fprintf('currently at line %i (taken %i)\n',i,lines_taken);end
    %if (mod(i,1e6)==0), verbose(sprintf('currently at line %d\n',i),20);end
    i = i+1;
    t1 = fgetl(f1); if ~ischar(t1), break; end
    if strcmp(t1(1:3),'@SQ'),
        tmpR = regexp(t1,'\t','split');
        chrCell = [chrCell tmpR{2}(find(tmpR{2}==':',1,'first')+1:end)]; %#ok<AGROW>
    end
    if t1(1)=='@', continue; end
    if length(chrCell)>1, 
        useChr = chrCell;
    else
        useChr = chrCellDef;
    end
    data = readSamLine(t1,useChr);
    
    tmp = bitget(data.Flag,1:11);
    flags = cell2struct(num2cell(tmp'),{'pairedInSeq','pairIsMapped','queryUnmapped','mateUnmapped','queryStrand','mateStrand','isRead1','isRead2','notPrimaryAlignment','failesQuality','isDuplicate'});
    
    paired = flags.pairedInSeq;
    flags.pairIsMapped = ~flags.queryUnmapped & ~flags.mateUnmapped;
    if (paired && ~flags.pairIsMapped) || ...
            (paired && flags.queryStrand==flags.mateStrand) || ...
            (paired && abs(data.InsertSize)>500) || ...
            flags.notPrimaryAlignment
        % paired lib, and mate is not mapped,
        % paired lib, and mate is on the same strand
        % paired lib, and insert size is longer than 500
        % this is not the primary mapping
        continue;
    end
    ch = data.ReferenceName;
    st1 = data.Position;
    [cigar.nums cigar.type] = strread(data.CigarString,'%d%[MIDNSHP]');
    cigar.ind = ~cellfun(@isempty,regexp(cigar.type,'[MDNX]'));
    matchLen = sum(cigar.nums(cigar.ind));
    en1 = st1+matchLen;
    wa1 = ~flags.queryStrand; %(0=forward, 1=reverse)
    
    if flags.isRead2 %IF THIS IS READ2, you should flip it now.
        wa1 = ~wa1;
    end
    
    if flip %IF THIS IS flipped, you should flip it now. (it might be flipped twice, for read2 and flip flag)
        wa1 = ~wa1;
    end
    
    if ch>chrNum || isempty(ch), continue; end
    
    num = 2;
    %ind = st1:en1;
    ind = [];
    offset = st1;
    for b = 1:length(cigar.nums),
      if cigar.type{b}=='M'
        new_ind = [offset:offset+cigar.nums(b)-1];
        offset = offset + cigar.nums(b);
        ind = [ind new_ind];
      elseif cigar.type{b}=='N'
        offset = offset + cigar.nums(b);
      elseif cigar.type{b}=='D'
        offset = offset + cigar.nums(b);
      end
    end
    assert(issorted(ind));
    assert(length(ind)==read_len-sum(cigar.nums(find([cigar.type{:}]=='I'))));
    
    indRead1 = [];
    if true%flags.isRead1
        indRead1 = ind;
    end
    
    if paired
        num = 1;
        if flip && flags.isRead2
            indRead1 = ind;
        end
    end
    
    if ind(end)>length(DataF{ch}) || ind(1)<=0, continue; end
    if wa1
        DataFconv{ch}(ind) = DataFconv{ch}(ind)+num;
        DataF{ch}(ind(1)) = DataF{ch}(ind(1))+1; %counting this one only as starts, no need to do internal normalization
        DataFread1{ch}(indRead1(1)) = DataFread1{ch}(indRead1(1))+1; %counting this one only as starts, no need to do internal normalization
    else
        DataRconv{ch}(ind) = DataRconv{ch}(ind)+num;
        DataR{ch}(ind(end)) = DataR{ch}(ind(end))+1; %counting this one only as starts, no need to do internal normalization
        DataRread1{ch}(indRead1(end)) = DataRread1{ch}(indRead1(end))+1; %counting this one only as starts, no need to do internal normalization
    end
    % sub-sample
    if sample_fac > rand(1)
      if wa1
        SubFconv{ch}(ind) = SubFconv{ch}(ind)+num;
        SubFread1_ext36{ch}(ind(1:36)) = SubFread1_ext36{ch}(ind(1:36))+1;
        SubFread1{ch}(indRead1(1)) = SubFread1{ch}(indRead1(1))+1; %counting this one only as starts, no need to do internal normalization
      else
        SubRconv{ch}(ind) = SubRconv{ch}(ind)+num;
        SubRread1_ext36{ch}(ind(end-35:end)) = SubRread1_ext36{ch}(ind(end-35:end))+1;
        SubRread1{ch}(indRead1(end)) = SubRread1{ch}(indRead1(end))+1; %counting this one only as starts, no need to do internal normalization
      end      
    end
    lines_taken = lines_taken + 1;
end
fclose(f1);
%% save for now (before sampling)
save(sprintf('%s/%s.mat', data_dir, name),'DataF', 'DataR','DataFconv','DataRconv');

%% total number of reads mapped
sumF = 0; sumR = 0;
sumFconv = 0; sumRconv = 0;
for c=1:chrNum
    sumF = sumF + sum(DataF{c});
    sumR = sumR + sum(DataR{c});
    sumFconv = sumFconv + sum(DataFconv{c});
    sumRconv = sumRconv + sum(DataRconv{c});
end

%% save into mat files
save(sprintf('%s/%s.mat', data_dir, name),'DataF', 'DataR','DataFconv','DataRconv',...
    'sumF', 'sumR', 'sumFconv', 'sumRconv', ...
    'SubFread1','SubRread1','DataFread1', 'DataRread1','paired',...
    'SubFread1_ext36','SubRread1_ext36', 'SubFconv', 'SubRconv');
toc;

end


%%

function data = readSamLine(tline,chrCell)


[rtext pos] = textscan(tline, '%s%u16%s%u32%u8%s%s%u32%d32%s%s',1, 'Delimiter', '\t');

rtext([1 3 6 7 10 11])=[rtext{[1 3 6 7 10 11]}];


optional_fields = regexp(tline(pos+1:end), '([^\s:]{2}):([AifZH]):(\S+)\t?', 'tokens');

if ~isempty(optional_fields)
    optional_fields = [optional_fields{:}]';
    tags = optional_fields(1:3:end);
    type = [optional_fields{2:3:end}];
    value = optional_fields(3:3:end);
    
    integers = type == 'i';
    if sum(integers)
        s = {' '};
        spaces = s(ones(1, sum(integers)));
        tmp = [value(integers)'; spaces];
        vals = [tmp{:}];
        value(integers) = num2cell(int32(str2num(vals))); %#ok<ST2NM>
    end
    
    floats = type == 'f';
    if sum(floats)
        s = {' '};
        spaces = s(ones(1, sum(floats)));
        tmp = [value(floats)'; spaces];
        vals = [tmp{:}];
        value(floats) = num2cell(single(str2num(vals))); %#ok<ST2NM>
    end
    
    hexstrings = strfind(type, 'H');
    if ~isempty(hexstrings)
        for hex_idx = 1:numel(hexstrings)
            value{hexstrings(hex_idx)} =  uint8(hex2dec(reshape(value{hexstrings(hex_idx)}, 2, [])')');
        end
    end
    
    if numel(value)~=numel(tags)
        error('Bioinfo:samread:ErrorInFile', 'Error in file at line %d.', n_headerrows+row)
    end
    
    data = cell2struct([rtext'; {cell2struct(value, tags)}], {'QueryName', 'Flag', 'ReferenceName', 'Position', ...
        'MappingQuality', 'CigarString', 'MateReferenceName', 'MatePosition', 'InsertSize', 'Sequence', 'Quality', 'Tags'});
    
else
    rtext(end+1) = {[]};
    data = cell2struct(rtext', {'QueryName', 'Flag', 'ReferenceName', 'Position', 'MappingQuality', 'CigarString', ...
        'MateReferenceName', 'MatePosition', 'InsertSize', 'Sequence', 'Quality', 'Tags'});
end %isempty(optional_fields)


data.ReferenceName = find(ismember(chrCell,data.ReferenceName));
end

%%
